"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import paperpilot_common.protobuf.common.util_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class UserId(google.protobuf.message.Message):
    """用户 ID"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """用户 UUID"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___UserId = UserId

@typing_extensions.final
class UserInfo(google.protobuf.message.Message):
    """用户简要信息 用于展示"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    id: builtins.str
    """用户 UUID"""
    username: builtins.str
    """用户名"""
    avatar: builtins.str
    """头像"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        username: builtins.str = ...,
        avatar: builtins.str = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["avatar", b"avatar", "id", b"id", "username", b"username"]
    ) -> None: ...

global___UserInfo = UserInfo

@typing_extensions.final
class UserDetail(google.protobuf.message.Message):
    """用户详细信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PHONE_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """用户 UUID"""
    username: builtins.str
    """用户名"""
    phone: builtins.str
    """手机号"""
    avatar: builtins.str
    """头像"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """创建时间"""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """更新时间"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        username: builtins.str = ...,
        phone: builtins.str = ...,
        avatar: builtins.str = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["create_time", b"create_time", "update_time", b"update_time"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "avatar",
            b"avatar",
            "create_time",
            b"create_time",
            "id",
            b"id",
            "phone",
            b"phone",
            "update_time",
            b"update_time",
            "username",
            b"username",
        ],
    ) -> None: ...

global___UserDetail = UserDetail

@typing_extensions.final
class CreateUserRequest(google.protobuf.message.Message):
    """创建用户请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHONE_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    phone: builtins.str
    """手机号"""
    code: builtins.str
    """验证码"""
    username: builtins.str
    """用户名"""
    password: builtins.str
    """密码"""
    def __init__(
        self,
        *,
        phone: builtins.str = ...,
        code: builtins.str = ...,
        username: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "code", b"code", "password", b"password", "phone", b"phone", "username", b"username"
        ],
    ) -> None: ...

global___CreateUserRequest = CreateUserRequest

@typing_extensions.final
class UpdateUserAvatarRequest(google.protobuf.message.Message):
    """更新用户头像请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    id: builtins.str
    """用户 UUID"""
    avatar: builtins.str
    """头像"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        avatar: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "id", b"id"]) -> None: ...

global___UpdateUserAvatarRequest = UpdateUserAvatarRequest

@typing_extensions.final
class UpdateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    OLD_PASSWORD_FIELD_NUMBER: builtins.int
    NEW_PASSWORD_FIELD_NUMBER: builtins.int
    PHONE_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """用户 UUID"""
    username: builtins.str
    """用户名"""
    old_password: builtins.str
    """旧密码"""
    new_password: builtins.str
    """新密码"""
    phone: builtins.str
    """手机号"""
    code: builtins.str
    """验证码"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        username: builtins.str = ...,
        old_password: builtins.str = ...,
        new_password: builtins.str = ...,
        phone: builtins.str = ...,
        code: builtins.str = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "code",
            b"code",
            "id",
            b"id",
            "new_password",
            b"new_password",
            "old_password",
            b"old_password",
            "phone",
            b"phone",
            "username",
            b"username",
        ],
    ) -> None: ...

global___UpdateUserRequest = UpdateUserRequest

@typing_extensions.final
class UserIdList(google.protobuf.message.Message):
    """用户 ID 列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDS_FIELD_NUMBER: builtins.int
    @property
    def ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ids", b"ids"]) -> None: ...

global___UserIdList = UserIdList

@typing_extensions.final
class UserInfoList(google.protobuf.message.Message):
    """用户简要信息列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserInfo]: ...
    def __init__(
        self,
        *,
        users: collections.abc.Iterable[global___UserInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["users", b"users"]) -> None: ...

global___UserInfoList = UserInfoList

@typing_extensions.final
class UploadUserAvatarResponse(google.protobuf.message.Message):
    """上传头像响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    @property
    def token(self) -> paperpilot_common.protobuf.common.util_pb2.OssToken: ...
    def __init__(
        self,
        *,
        token: paperpilot_common.protobuf.common.util_pb2.OssToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token", b"token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token"]) -> None: ...

global___UploadUserAvatarResponse = UploadUserAvatarResponse
