# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: paperpilot_common/protobuf/im/im.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n&paperpilot_common/protobuf/im/im.proto\x12\x02im\x1a\x1bgoogle/protobuf/empty.proto")\n\x0eIMAuthResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03sig\x18\x02 \x01(\t"A\n\x11\x43reateUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t"A\n\x11UpdateUserRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\t"A\n\x16\x43reateWorkGroupRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t"2\n\x16UpdateWorkGroupRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t"$\n\x16\x44\x65leteWorkGroupRequest\x12\n\n\x02id\x18\x01 \x01(\t"=\n\x18InviteUserToGroupRequest\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t"?\n\x1aRemoveUserFromGroupRequest\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t2\xf4\x03\n\tIMService\x12;\n\nCreateUser\x12\x15.im.CreateUserRequest\x1a\x16.google.protobuf.Empty\x12;\n\nUpdateUser\x12\x15.im.UpdateUserRequest\x1a\x16.google.protobuf.Empty\x12\x45\n\x0f\x43reateWorkGroup\x12\x1a.im.CreateWorkGroupRequest\x1a\x16.google.protobuf.Empty\x12\x45\n\x0fUpdateWorkGroup\x12\x1a.im.UpdateWorkGroupRequest\x1a\x16.google.protobuf.Empty\x12\x45\n\x0f\x44\x65leteWorkGroup\x12\x1a.im.DeleteWorkGroupRequest\x1a\x16.google.protobuf.Empty\x12I\n\x11InviteUserToGroup\x12\x1c.im.InviteUserToGroupRequest\x1a\x16.google.protobuf.Empty\x12M\n\x13RemoveUserFromGroup\x12\x1e.im.RemoveUserFromGroupRequest\x1a\x16.google.protobuf.Empty2G\n\x0fIMPublicService\x12\x34\n\x06IMAuth\x12\x16.google.protobuf.Empty\x1a\x12.im.IMAuthResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "paperpilot_common.protobuf.im.im_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_IMAUTHRESPONSE"]._serialized_start = 75
    _globals["_IMAUTHRESPONSE"]._serialized_end = 116
    _globals["_CREATEUSERREQUEST"]._serialized_start = 118
    _globals["_CREATEUSERREQUEST"]._serialized_end = 183
    _globals["_UPDATEUSERREQUEST"]._serialized_start = 185
    _globals["_UPDATEUSERREQUEST"]._serialized_end = 250
    _globals["_CREATEWORKGROUPREQUEST"]._serialized_start = 252
    _globals["_CREATEWORKGROUPREQUEST"]._serialized_end = 317
    _globals["_UPDATEWORKGROUPREQUEST"]._serialized_start = 319
    _globals["_UPDATEWORKGROUPREQUEST"]._serialized_end = 369
    _globals["_DELETEWORKGROUPREQUEST"]._serialized_start = 371
    _globals["_DELETEWORKGROUPREQUEST"]._serialized_end = 407
    _globals["_INVITEUSERTOGROUPREQUEST"]._serialized_start = 409
    _globals["_INVITEUSERTOGROUPREQUEST"]._serialized_end = 470
    _globals["_REMOVEUSERFROMGROUPREQUEST"]._serialized_start = 472
    _globals["_REMOVEUSERFROMGROUPREQUEST"]._serialized_end = 535
    _globals["_IMSERVICE"]._serialized_start = 538
    _globals["_IMSERVICE"]._serialized_end = 1038
    _globals["_IMPUBLICSERVICE"]._serialized_start = 1040
    _globals["_IMPUBLICSERVICE"]._serialized_end = 1111
# @@protoc_insertion_point(module_scope)
